@@ -22,31 +22,31 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
-           '-DNDEBUG    -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-DNDEBUG  -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
            '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -fexceptions '
-           '-g -grecord-gcc-switches -pipe -Wall -Werror=format-security '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
-           '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
-           '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
-           '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
-           '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
-           '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-D_GNU_SOURCE -fPIC -fwrapv  -O3',
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
+           '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+           '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
+           '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+           '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+ 'CONFIGURE_CFLAGS': '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                      '-m64 -march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv',
- 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -89,7 +89,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-builtin-hashlib-hashes=blake2' '--with-valgrind' "
                 "'--without-ensurepip' '--enable-optimizations' "
                 "'build_alias=s390x-redhat-linux-gnu' "
-                "'host_alias=s390x-redhat-linux-gnu' 'CC=gcc' 'CFLAGS=   "
+                "'host_alias=s390x-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                 '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
@@ -101,12 +101,12 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.19/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.19/build/optimized/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.21/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.21/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.9.19/Include',
+             '-I/builddir/build/BUILD/Python-3.9.21/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.9 '
              '/usr/lib64/python3.9/lib-dynload',
@@ -626,7 +626,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.19/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.21/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -656,7 +656,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
         '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
@@ -695,7 +695,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -703,21 +703,21 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong   -m64 -march=z14 '
                              '-mtune=z15 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fexceptions -g -grecord-gcc-switches '
-                             '-pipe -Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv -O2  -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=z14 '
                              '-mtune=z15 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv    -fexceptions -g -grecord-gcc-switches '
-                             '-pipe -Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv  -O2  -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=z14 '
                              '-mtune=z15 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -O3 -flto=auto -ffat-lto-objects '
+                             '-fwrapv -O2 -flto=auto -ffat-lto-objects '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -734,10 +734,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
-                             '-fexceptions -g -grecord-gcc-switches -pipe '
-                             '-Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fvisibility=hidden -O2 -flto=auto '
+                             '-ffat-lto-objects -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
@@ -745,30 +745,30 @@ build_time_vars = {'ABIFLAGS': '',
                              '-m64 -march=z14 -mtune=z15 '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fno-semantic-interposition -O3 '
+                             '-fwrapv -fno-semantic-interposition  -O3 '
                              '-fprofile-use -fprofile-correction '
-                             '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.9.21/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.9.19/Include '
+                             '-I/builddir/build/BUILD/Python-3.9.21/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=z14 -mtune=z15 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv  -O3',
- 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv',
+ 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -782,7 +782,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -791,27 +791,27 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                      '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                     '-fno-semantic-interposition -O3 -fprofile-use '
+                     '-fno-semantic-interposition  -O3 -fprofile-use '
                      '-fprofile-correction '
-                     '-I/builddir/build/BUILD/Python-3.9.19/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.9.21/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions '
-                   '-g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-                   '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv    '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3 '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
+                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+                   '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2 '
                    '-flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
@@ -825,7 +825,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -833,11 +833,11 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition -O3 -fprofile-use '
+                   '-fno-semantic-interposition  -O3 -fprofile-use '
                    '-fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.9.21/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.9.21/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
                     '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g '
@@ -851,7 +851,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-fno-semantic-interposition -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.9.19/Include',
+                '-I/builddir/build/BUILD/Python-3.9.21/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
                '-Wl,--as-needed  -Wl,-z,now    -g',
@@ -868,25 +868,25 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=z14 -mtune=z15 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=z14 -mtune=z15 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=z14 -mtune=z15 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -O3 -flto=auto '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -O2 -flto=auto '
                         '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -901,7 +901,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -910,11 +910,11 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                         '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
                         '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition -O3 -fprofile-use '
+                        '-fno-semantic-interposition  -O3 -fprofile-use '
                         '-fprofile-correction '
-                        '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.9.21/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.9.21/Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -923,7 +923,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.19/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.21/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -952,7 +952,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39-s390x-linux-gnu',
  'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.19/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.21/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -964,12 +964,12 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.19/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.21/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.19/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.21/build/optimized '
                './python '
-               '/builddir/build/BUILD/Python-3.9.19/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.9.21/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -978,10 +978,10 @@ build_time_vars = {'ABIFLAGS': '',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.9 '
-                '/builddir/build/BUILD/Python-3.9.19/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.9.21/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.9',
- 'VPATH': '/builddir/build/BUILD/Python-3.9.19',
+ 'VPATH': '/builddir/build/BUILD/Python-3.9.21',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -993,9 +993,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.9.19/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.19',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.9.21/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.21',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.9.19'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.9.21'}
